Documentation
¶
Index ¶
- Variables
- func ApplyDefaultsSubs(str string) (string, error)
- func ApplySubsReplacer(str string, repler *strings.Replacer) string
- func GetGlobalMetadata(ddirpath string) error
- func IsExcluded(fname []byte) (bool, error)
- func SubsApply(s string) (string, error)
- type Metadata
- type SubsDef
- type SubsRules
Constants ¶
This section is empty.
Variables ¶
var GlobalMetaData = Metadata{ // contains filtered or unexported fields }
GlobalMetaData stores global metadata, load before use
Functions ¶
func ApplyDefaultsSubs ¶
ApplyDefaultSubs applies the default subs rules to string, note that it does not include special hd subs
func ApplySubsReplacer ¶
ApplySubsReplacer applies a set of subs rules to string
func GetGlobalMetadata ¶
func IsExcluded ¶
Types ¶
type Metadata ¶
Click to show internal directories.
Click to hide internal directories.